**eZadb**
=========

*eZadb* is a python application that aims to provide the **Android Debug
Bridge** (adb) funcionalities in more simple and intuitive way.

ezadb has two modes:

-  **command-line**: this mode allows you to use some of the most common
   adb commands, e.g.: install/uninstall packages; grant/revoke
   permissions; input text; etc.
-  **graphical mode**: this mode provides almost the same features as
   the command-line mode but in a more intuitive way.

To install go to the command line and type:

.. code:: python

     pip install ezadb

**Command Line Tool**
---------------------

.. figure:: https://filipebatista.github.io/eZadb/imgs/command_line_thumb.png
   :alt: command line

   command line

Contributing
------------

Please read
`CONTRIBUTING.md <https://filipebatista.github.io/eZadb/CONTRIBUTING.md>`__
for details on our code of conduct, and the process for submitting pull
requests to us.

Authors
-------

-  **Filipe Baptista** -
   `filipebatista <https://github.com/filipebatista>`__

See also the list of
`contributors <https://github.com/filipebatista/eZadb/contributors>`__
who participated in this project.

Acknowledgements
----------------

A big thanks to **Artur Costa** - `cosart <https://github.com/cosart>`__
that helped in the beginning of the project.

License
-------

eZadb is made available under the terms of the GPLv3.

See the
`LICENSE <https://github.com/filipebatista/eZadb/blob/master/LICENSE>`__
file that accompanies this distribution for the full text of the
license.
